==> pegasus-support-2.5.6-sources.jar: com/thebeastshop/support/vo/order/OrderActionVO.java <==
package com.thebeastshop.support.vo.order;

import com.thebeastshop.support.vo.product.ProductLotteryShareVO;
import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * @author Paul-xiong
 */
public class OrderActionVO {

    /**
     * 分享
     */
    private ProductLotteryShareVO share = new ProductLotteryShareVO();

    /**
     * 后续的行为
     */
    private String webview;

    /**
     * 是否显示 webview
     */
    private boolean wvVisible;

    /**
     * 兑换链接
     */
    private Object exchangeLink;

    /**
     * 购物基金链接
     */
    private Object shoppingFundLink;

    public boolean isWvVisible() {
        return wvVisible;
    }

    public void setWvVisible(boolean wvVisible) {
        this.wvVisible = wvVisible;
    }

    public ProductLotteryShareVO getShare() {
        return share;
    }

    public void setShare(ProductLotteryShareVO share) {
        this.share = share;
    }

    public String getWebview() {
        return webview;
    }

    public void setWebview(String webview) {
        this.webview = webview;
    }

    public Object getExchangeLink() {
        return exchangeLink;
    }

    public void setExchangeLink(Object exchangeLink) {
        this.exchangeLink = exchangeLink;
    }

    public Object getShoppingFundLink() {
        return shoppingFundLink;
    }

    public void setShoppingFundLink(Object shoppingFundLink) {
        this.shoppingFundLink = shoppingFundLink;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("share", share)
                .append("webview", webview)
                .append("wvVisible", wvVisible)
                .append("exchangeLink", exchangeLink)
                .append("shoppingFundLink", shoppingFundLink)
                .toString();
    }
}

==> pegasus-support-2.7.5-sources.jar: com/thebeastshop/support/vo/order/OrderActionVO.java <==
package com.thebeastshop.support.vo.order;

import com.thebeastshop.support.vo.product.ProductLotteryShareVO;
import org.apache.commons.lang3.builder.ToStringBuilder;

/**
 * @author Paul-xiong
 */
public class OrderActionVO {

    /**
     * 裂变分享
     */
    private ProductLotteryShareVO share = new ProductLotteryShareVO();

    /**
     * 小程序分享
     */
    private OrderAppletShareVO appletShare;

    /**
     * webview地址
     */
    private String webview;

    /**
     * 是否显示 webview
     */
    private boolean wvVisible;

    /**
     * 兑换链接
     */
    private Object exchangeLink;

    /**
     * 购物基金链接
     */
    private Object shoppingFundLink;


    public boolean isWvVisible() {
        return wvVisible;
    }

    public void setWvVisible(boolean wvVisible) {
        this.wvVisible = wvVisible;
    }

    public ProductLotteryShareVO getShare() {
        return share;
    }

    public void setShare(ProductLotteryShareVO share) {
        this.share = share;
    }

    public String getWebview() {
        return webview;
    }

    public void setWebview(String webview) {
        this.webview = webview;
    }

    public Object getExchangeLink() {
        return exchangeLink;
    }

    public void setExchangeLink(Object exchangeLink) {
        this.exchangeLink = exchangeLink;
    }

    public Object getShoppingFundLink() {
        return shoppingFundLink;
    }

    public void setShoppingFundLink(Object shoppingFundLink) {
        this.shoppingFundLink = shoppingFundLink;
    }

    public OrderAppletShareVO getAppletShare() {
        return appletShare;
    }

    public void setAppletShare(OrderAppletShareVO appletShare) {
        this.appletShare = appletShare;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this)
                .append("share", share)
                .append("webview", webview)
                .append("wvVisible", wvVisible)
                .append("exchangeLink", exchangeLink)
                .append("shoppingFundLink", shoppingFundLink)
                .toString();
    }
}
